@@ -112,13 +112,7 @@
 	on.exit( close.ncdf(nc) )
 	
 	conv <- att.get.ncdf(nc, 0, "Conventions")
-	if (substr(conv$value, 1, 3) == 'RST') {
-		close.ncdf(nc)
-		return( .rasterObjectFromCDFrst(filename, band=band, type='RasterLayer', ...) )
-	} else {
-		conv <- 'CF'
-		# assuming "CF-1.0"
-	}
+	# assuming "CF-1.0"
 	
 	zvar <- .varName(nc, varname)
 	
@@ -262,7 +256,7 @@
 		r@data@nlayers <- r@file@nbands
 		r@data@min <- rep(Inf, r@file@nbands)
 		r@data@max <- rep(-Inf, r@file@nbands)
-		try( layerNames(r) <- r@zvalue, silent=TRUE )
+		try( layerNames(r) <- as.character(r@zvalue), silent=TRUE )
 	}
 	
 	return(r)
