@@ -6,22 +6,12 @@
 
 .rasterSaveAsNetCDF <- function(x, filename, datatype='FLT4S', overwrite=FALSE, convention='CF', ...) {
 
-	if (convention=='RST') {
-		x <- .startWriteCDFrst(x, filename=filename, datatype=datatype, overwrite=overwrite, ...)
-		if (inherits(x, 'RasterBrick')) {
-			x <- .writeValuesBrickCDFrst(x, getValues(x) )	
-		} else {
-			x <- .writeValuesCDFrst(x, getValues(x))
-		}
+	x <- .startWriteCDF(x, filename=filename, datatype=datatype, overwrite=overwrite, ...)
+	if (inherits(x, 'RasterBrick')) {
+		x <- .writeValuesBrickCDF(x, getValues(x) )	
 	} else {
-		x <- .startWriteCDF(x, filename=filename, datatype=datatype, overwrite=overwrite, ...)
-		if (inherits(x, 'RasterBrick')) {
-			x <- .writeValuesBrickCDF(x, getValues(x) )	
-		} else {
-			x <- .writeValuesCDF(x, getValues(x))
-		}
+		x <- .writeValuesCDF(x, getValues(x))
 	}
-
 	return( .stopWriteCDF(x) )
 }
 
@@ -185,3 +175,4 @@
 #plot(a)
 #print(a)
 
+
