@@ -47,9 +47,14 @@ setMethod('predict', signature(object='Raster'),
 		}
 			
 		
+		
 		f <- names( which(dataclasses == 'factor') )
 		if (length(f) > 0) { 
 			haveFactor <- TRUE 
+			factlevels <- list()
+			for (i in 1:length(f)) {
+				factlevels[[i]] <- levels(model$data[f][,1])
+			}
 		} else {
 			haveFactor <- FALSE
 		}
@@ -93,9 +98,13 @@ setMethod('predict', signature(object='Raster'),
 			rr <- firstrow + tr$row[i] - 1
 		
 			blockvals <- as.data.frame(getValuesBlock(object, row=rr, nrows=tr$nrows[i], firstcol, ncols))
+			colnames(blockvals) <- lyrnames
 			if (haveFactor) {
-				for (i in 1:length(f)) {
-					blockvals[,f[i]] <- as.factor(blockvals[,f[i]])
+				for (j in 1:length(f)) {
+					fv <- blockvals[,f[j]]
+					fv[! fv %in% factlevels[[j]] ] <- NA
+					blockvals[,f[j]] <- as.factor(fv)
+					na.rm <- TRUE
 				}
 			}
 			if (! is.null(const)) {
@@ -127,15 +136,15 @@ setMethod('predict', signature(object='Raster'),
 					if (isTRUE(dim(predv)[2] > 1)) {
 						predv = predv[,index]
 					}
-				}
-						
-				if (na.rm) {  
-					naind <- as.vector(attr(blockvals, "na.action"))
-					if (!is.null(naind)) {
-						p <- napred
-						p[-naind] <- predv
-						predv <- p
-						rm(p)
+										
+					if (na.rm) {  
+						naind <- as.vector(attr(blockvals, "na.action"))
+						if (!is.null(naind)) {
+							p <- napred
+							p[-naind] <- predv
+							predv <- p
+							rm(p)
+						}
 					}
 				}
 			}
@@ -145,7 +154,7 @@ setMethod('predict', signature(object='Raster'),
 		
 			if (filename == '') {
 				cells = cellFromRowCol(predrast, tr$row[i], 1):cellFromRowCol(predrast, tr$row[i]+tr$nrows[i]-1, ncol(predrast))
-				a = v[cells, ] <- predv 
+				v[cells, ] <- predv 
 			} else {
 				predrast <- writeValues(predrast, predv, tr$row[i])
 			}
