@@ -12,12 +12,13 @@ if (!isGeneric("rotate")) {
 
 setMethod('rotate', signature(x='Raster'), 
 	function(x, ...) {
-		xr <- xmax(x) - xmin(x)
+		e <- extent(x)
+		xr <- xmax(e) - xmin(e)
 		hx <- xr / 2
-		r1 <- crop(x, extent(xmin(x), hx, ymin(x), ymax(x)))
-		r2 <- crop(x, extent(hx, xmax(x), ymin(x), ymax(x)))
-		xmax(r2) <- xmax(r2) - xr
-		xmin(r2) <- xmin(r2) - xr
+		r1 <- crop(x, extent(xmin(e), hx, ymin(e), ymax(e)))
+		r2 <- crop(x, extent(hx, xmax(e), ymin(e), ymax(e)))
+		r2@extent@xmin <- r2@extent@xmin - xr
+		r2@extent@xmax <- r2@extent@xmax - xr
 		m <- merge(r1, r2, ...)	
 		m@layernames <- layerNames(x)
 		return(m)
